@@ -6,8 +6,13 @@ mod syscalls;
 mod type_id;
 mod types;
 mod verify;
+mod verify_env;
 
 pub use crate::error::{ScriptError, TransactionScriptError};
 pub use crate::ill_transaction_checker::IllTransactionChecker;
-pub use crate::types::{ScriptGroup, ScriptGroupType};
+pub use crate::types::{
+    CoreMachine, ScriptGroup, ScriptGroupType, ScriptVersion, TransactionSnapshot,
+    TransactionState, VerifyResult, VmIsa, VmVersion,
+};
 pub use crate::verify::TransactionScriptsVerifier;
+pub use crate::verify_env::TxVerifyEnv;
