@@ -112,7 +112,12 @@ impl<'a, DL: CellDataProvider + 'a> LoadCell<'a, DL> {
                 let mut buffer = vec![];
                 buffer.write_u64::<LittleEndian>(
                     cell.occupied_capacity()
-                        .map_err(|_| VMError::Unexpected)?
+                        .map_err(|_| {
+                            VMError::Unexpected(format!(
+                                "Unexpected occupied_capacity overflow {}",
+                                cell.out_point,
+                            ))
+                        })?
                         .as_u64(),
                 )?;
                 (SUCCESS, store_data(machine, &buffer)?)
@@ -174,7 +179,7 @@ impl<'a, Mac: SupportMachine, DL: CellDataProvider> Syscalls<Mac> for LoadCell<'
             self.load_full(machine, &cell.cell_output)?
         };
 
-        machine.add_cycles(transferred_byte_cycles(len as u64))?;
+        machine.add_cycles_no_checking(transferred_byte_cycles(len as u64))?;
         machine.set_register(A0, Mac::REG::from_u8(return_code));
         Ok(true)
     }
